@@ -618,10 +618,13 @@ def plot_boxplot(data: Dict[str, pd.DataFrame],
                  plot_fig_size: Tuple[int, int] = (10, 18),
                  plot_hspace: float = 0.4,
                  difference_dist: bool = False,
-                 as_subplots: bool = True
+                 as_subplots: bool = True,
+                 z_scores: bool = True
                  ) -> plt.Figure:
     if as_subplots:
-        def plot_boxes(ax, data, key, difference_dist):
+        def plot_boxes(ax, data, key, difference_dist, z_scores):
+            if z_scores:
+                data["value"] = (data['value'] - data['value'].mean()) / data['value'].std()
             if "groups" in data.columns:
                 sns.boxplot(
                     ax=ax,
@@ -641,16 +644,19 @@ def plot_boxplot(data: Dict[str, pd.DataFrame],
                 ax.set(ylabel='Ratio')
         return plot_template(
             data, plot_boxes, plot_n_col, plot_fig_size,
-            plot_hspace, difference_dist=difference_dist
+            plot_hspace, difference_dist=difference_dist,
+            z_scores=z_scores
         )
     else:
         fig, ax = plt.subplots(figsize=plot_fig_size)
         dfs = []
         for reaction, df in data.items():
+            if z_scores:
+                df["value"] = (df['value'] - df['value'].mean()) / df['value'].std()
             df['Reaction'] = reaction
             dfs.append(df)
         df_data = pd.concat(dfs)
-        print(df_data)
+
         if 'groups' in df_data.columns:
             sns.boxplot(
                 ax=ax,
@@ -972,4 +978,5 @@ def _add_missing_rows_(
     for spec in species:
         if full_data.get(spec) is None:
             full_data[spec] = dummy
-    return pd.DataFrame(full_data).T
\ No newline at end of file
+    return pd.DataFrame(full_data).T
+
